The MPL Reference Manual: Configuration

Prev Next | Back Along | Up Home | Full TOC | Front Page / Macros / Configuration

# Configuration

- BOOST_MPL_CFG_NO_PREPROCESSED_HEADERS
- BOOST_MPL_CFG_NO_HAS_XXX
- BOOST_MPL_CFG_NO_HAS_XXX_TEMPLATE
- BOOST_MPL_LIMIT_METAFUNCTION_ARITY
- BOOST_MPL_LIMIT_VECTOR_SIZE
- BOOST_MPL_LIMIT_LIST_SIZE
- BOOST_MPL_LIMIT_SET_SIZE
- BOOST_MPL_LIMIT_MAP_SIZE
- BOOST_MPL_LIMIT_STRING_SIZE
- BOOST_MPL_LIMIT_UNROLLING

Prev Next | Back Along | Up Home | Full TOC | Copyright © 2001-2009 Aleksey Gurtovoy and David Abrahams Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)